@@ -1,6 +1,6 @@
 package Tapper::Cmd::Testplan;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Cmd::Testplan::VERSION = '5.0.1';
+$Tapper::Cmd::Testplan::VERSION = '5.0.2';
 use 5.010;
 use Moose;
 
@@ -118,8 +118,10 @@ sub get_shortname {
     my ( $or_self, $s_plan ) = @_;
 
     foreach my $s_line ( split /\n/, $s_plan ) {
-        if ( $s_line =~ /^\s*-?\s*(?:short)?name\s*:\s*(.+?)\s*$/i ) {
-            return $1;
+        if ( $s_line =~ /^[#\s]*-?\s*(?:short)?name\s*:\s*(.+?)\s*$/i ) {
+            my $shortname = $1;
+            $shortname =~ s/['"]+//g;
+            return $shortname;
         }
     }
 
